summaryrefslogtreecommitdiffstats
path: root/korganizer/koeditordetails.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koeditordetails.cpp')
-rw-r--r--korganizer/koeditordetails.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/koeditordetails.cpp b/korganizer/koeditordetails.cpp
index adeb9bb0..ebc70200 100644
--- a/korganizer/koeditordetails.cpp
+++ b/korganizer/koeditordetails.cpp
@@ -92,14 +92,14 @@ void CustomListViewItem<KCal::Attendee *>::updateItem()
}
KOAttendeeListView::KOAttendeeListView ( TQWidget *parent, const char *name )
- : KListView(parent, name)
+ : TDEListView(parent, name)
{
setAcceptDrops( true );
setAllColumnsShowFocus( true );
setSorting( -1 );
}
/** KOAttendeeListView is a child class of KListView which supports
* dropping of attendees (e.g. from kaddressbook) onto it. If an attendeee
* was dropped, the signal dropped(Attendee*) is emitted. Valid drop classes
* are KVCardDrag and TQTextDrag.
@@ -265,7 +265,7 @@ void KOEditorDetails::insertAttendee( Attendee *a, bool goodEmailAddress )
// lastItem() is O(n), but for n very small that should be fine
AttendeeListItem *item = new AttendeeListItem(
- a, mListView, static_cast<KListViewItem*>( mListView->lastItem() ) );
+ a, mListView, static_cast<TDEListViewItem*>( mListView->lastItem() ) );
mListView->setSelected( item, true );
emit updateAttendeeSummary( mListView->childCount() );
}
@@ -92,14 +92,14 @@ void CustomListViewItem<KCal::Attendee *>::updateItem()
setSorting( -1 );
}
-/** KOAttendeeListView is a child class of KListView which supports
+/** KOAttendeeListView is a child class of TDEListView which supports
* dropping of attendees (e.g. from kaddressbook) onto it. If an attendeee
* was dropped, the signal dropped(Attendee*) is emitted. Valid drop classes